@@ -65,7 +65,7 @@ Version 0.16
 
 =cut
 
-$VERSION = '1.01_03';
+$VERSION = '1.02_01';
 
 =head1 SYNOPSIS
 
@@ -112,8 +112,7 @@ however, the features provided by L<Sub::Exporter> over what L<Exporter>
 provides is just to great to pass up.
 
 Likewise, Capture::Tiny provides a much more robust capture mechanism without
-than the original Test::Output::Tie.  (Test::Output::Tie is deprecated, but
-included for backwards compatibility.)
+than the original Test::Output::Tie.
 
 =cut
 
@@ -241,6 +240,7 @@ sub stdout_unlike (&$;$$) {
 
    stderr_is  ( $coderef, $expected, 'description' );
    stderr_is    {... } $expected, 'description';
+
    stderr_isnt( $coderef, $expected, 'description' );
    stderr_isnt  {... } $expected, 'description';
 
@@ -486,7 +486,7 @@ is functionally equivalent to
 except that $coderef is only executed once.
 
 Unlike, stdout_is() and stderr_is() which ignore STDERR and STDOUT
-repectively, output_is() requires both STDOUT and STDERR to match in order
+respectively, output_is() requires both STDOUT and STDERR to match in order
 to pass. Setting either $expected_stdout or $expected_stderr to C<undef>
 ignores STDOUT or STDERR respectively.
 
@@ -938,7 +938,7 @@ be notified of progress on your bug as I make changes.
 
 Thanks to chromatic whose TieOut.pm was the basis for capturing output.
 
-Also thanks to rjbs for his help cleaning the documention, and pushing me to
+Also thanks to rjbs for his help cleaning the documentation, and pushing me to
 L<Sub::Exporter>.
 
 Thanks to David Wheeler for providing code block support and tests.
@@ -947,7 +947,7 @@ Thanks to Michael G Schwern for the solution to combining STDOUT and STDERR.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005-2008 Shawn Sorichetti, All Rights Reserved.
+Copyright 2005-2013 Shawn Sorichetti, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
